
***================税收激励与企业绿色创新：来自中国加速折旧政策的证据=================***
cd "~\财经问题研究\税收激励与绿色创新\（20240522）税收激励与绿色创新：数据代码"
use 税收激励与企业绿色创新基础数据集.dta,clear

/*+++++注释+++++
接下来依次展示正文图表的数据、代码；
代码运行版本为Stata/SE 16.0。
回归分析中主要使用reghdfe命令，附加keepsing选项（即保留单例观测值）；
一方面本文样本中的单例观测值仅为5个，是否保留不会影响回归结果；另一方面
使用keepsing选项后可以保证回归中的样本量与使用其他命令如xtreg、areg时一致，避免读者产生误会。

Treat：是否处理组
ADP：政策变量
lnGI：绿色创新
lnGINV：绿色投资
Size：企业规模
Roa：总资产收益率
Age：企业年龄的对数
Institution：机构持股比例
Controlling：控股股东持股比例
Top10：前10大股东持股比例
indsize： 行业总资产的对数
indroa：行业总资产收益率
indleverage： 行业杠杆率
indcapexp：行业固定资产投资比率
t：时间趋势项
*/
global firmcontrols  Size Roa Age Institution Controlling Top10
global indcontrols c.indsize#c.t  c.indroa#c.t  c.indleverage#c.t c.indcapexp#c.t

*~~~表1 描述性统计~~~*
summarize lnGI ADP Treat  lnGINV $firmcontrols

/*导出到word
sum2docx lnGI ADP Treat  lnGINV $firmcontrols using 描述统计.docx,replace   ///
stats(N mean(%9.3f) sd(%9.3f) min(%9.3f) max(%9.3f))  ///
title("表1 描述性统计结果") 
*/

*~~~表2 基准回归结果~~~*
  quietly reghdfe lnGI ADP, absorb(year stockcd) cluster(stockcd) keepsing
  est store m1
  quietly reghdfe lnGI ADP Size Roa Age, absorb(year stockcd) cluster(stockcd) keepsing
  est store m2
  quietly reghdfe lnGI ADP $firmcontrols, absorb(year stockcd) cluster(stockcd) keepsing
  est store m3
  quietly reghdfe lnGI ADP $firmcontrols $indcontrols, absorb(year stockcd) cluster(stockcd)  keepsing
  est store m4
  esttab m1 m2 m3 m4,b(%9.3f) se(%9.3f)  obslast star(* 0.1 ** 0.05 *** 0.01)  compress nogap  stat(N r2_a, fmt(%9.0f  %9.3f)) varwidth(20) 

*~~~表3 列（1）至列（4）机制分析：融资约束~~~*  
  quietly reghdfe lnGI ADP $firmcontrols $indcontrols if HKZ == 1, absorb(year stockcd) cluster(stockcd)  keepsing
  est store m1
  quietly reghdfe lnGI ADP $firmcontrols $indcontrols if HKZ == 0, absorb(year stockcd) cluster(stockcd) keepsing
  est store m2
  quietly reghdfe lnGI ADP $firmcontrols $indcontrols if HSA ==1, absorb(year stockcd) cluster(stockcd) keepsing
  est store m3
  quietly reghdfe lnGI ADP $firmcontrols $indcontrols if HSA == 0, absorb(year stockcd) cluster(stockcd) keepsing
  est store m4
  esttab m1 m2 m3 m4,b(%9.3f) se(%9.3f)  obslast star(* 0.1 ** 0.05 *** 0.01)  compress nogap  stat(N r2_a, fmt(%9.0f  %9.3f)) varwidth(20) 
  
*~~~表3  列（5）至列（8）机制分析：加速折旧政策对企业绿色投资的影响~~~*  
  quietly reghdfe lnGINV ADP, absorb(year stockcd) cluster(stockcd) keepsing
  est store m1
  quietly reghdfe lnGINV ADP $firmcontrols $indcontrols, absorb(year stockcd) cluster(stockcd) keepsing
  est store m2
  quietly reghdfe yfGINV ADP $firmcontrols $indcontrols, absorb(year stockcd) cluster(stockcd) keepsing
  est store m3
  quietly reghdfe zlGINV ADP $firmcontrols $indcontrols, absorb(year stockcd) cluster(stockcd) keepsing
  est store m4
  esttab m1 m2 m3 m4,b(%9.3f) se(%9.3f)  obslast star(* 0.1 ** 0.05 *** 0.01) compress nogap  stat(N r2_a, fmt(%9.0f  %9.3f)) varwidth(20) 
  
*~~~表4列（1）至列（4） 机制分析：基于绿色投资的分组检验~~~*   
  quietly reghdfe lnGI ADP $firmcontrols $indcontrols if incGI == 1, absorb(year stockcd) cluster(stockcd) keepsing
  est store m1
  quietly reghdfe lnGI ADP $firmcontrols $indcontrols if incGI == 0, absorb(year stockcd) cluster(stockcd) keepsing
  est store m2
  quietly reghdfe lnGI ADP $firmcontrols $indcontrols if incyfGI ==1, absorb(year stockcd) cluster(stockcd) keepsing
  est store m3
  quietly reghdfe lnGI ADP $firmcontrols $indcontrols if incyfGI == 0, absorb(year stockcd) cluster(stockcd) keepsing
  est store m4
  esttab m1 m2 m3 m4,b(%9.3f) se(%9.3f)  obslast star(* 0.1 ** 0.05 *** 0.01)  compress nogap  stat(N r2_a, fmt(%9.0f  %9.3f)) varwidth(20) 
  
*~~~表4 （5）至列（8）机制分析：基于市场竞争的分组检验~~~*  
 quietly reghdfe lnGI ADP $firmcontrols $indcontrols if Lowhhi ==  1, absorb(year stockcd) cluster(stockcd) keepsing
 est store m1
 quietly reghdfe lnGI ADP $firmcontrols $indcontrols if Lowhhi ==  0, absorb(year stockcd) cluster(stockcd) keepsing
 est store m2
 quietly reghdfe lnGI ADP $firmcontrols $indcontrols if Lowprofit == 1, absorb(year stockcd) cluster(stockcd) keepsing
 est store m3
 quietly reghdfe lnGI ADP $firmcontrols $indcontrols if Lowprofit == 0, absorb(year stockcd) cluster(stockcd)  keepsing
 est store m4
 esttab m1 m2 m3 m4,b(%9.3f) se(%9.3f)  obslast star(* 0.1 ** 0.05 *** 0.01)  compress nogap  stat(N r2_a, fmt(%9.0f  %9.3f)) varwidth(20)  
 
*~~~表5 环境规制的调节效应~~~*   
*列(1)-列(2)
  rename mprover ER1
  quietly reghdfe lnGI ADP c.ADP#c.ER1, absorb(year stockcd) cluster(stockcd)  keepsing
  est store m1
  quietly reghdfe lnGI ADP c.ADP#c.ER1 $firmcontrols $indcontrols, absorb(year stockcd) cluster(stockcd)  keepsing
  est store m2
  esttab m1 m2,b(%9.3f) se(%9.3f)  obslast star(* 0.1 ** 0.05 *** 0.01)  order(ADP  c.ADP#c.ER1) compress nogap  stat(N r2_a, fmt(%9.0f  %9.3f)) varwidth(20) 

*列(3)-列(4)
  rename mUtilizationR ER2
  quietly reghdfe lnGI ADP c.ADP#c.ER2, absorb(year stockcd) cluster(stockcd)  keepsing
  est store m1
  quietly reghdfe lnGI ADP c.ADP#c.ER2 $firmcontrols $indcontrols, absorb(year stockcd) cluster(stockcd)  keepsing
  est store m2
  esttab m1 m2,b(%9.3f) se(%9.3f)  obslast star(* 0.1 ** 0.05 *** 0.01)  order(ADP  c.ADP#c.ER2) compress nogap  stat(N r2_a, fmt(%9.0f  %9.3f)) varwidth(20) 
  
*列(5)-列(6)
  rename dtcs ER3
  quietly reghdfe lnGI ADP c.ADP#c.ER3, absorb(year stockcd) cluster(stockcd)  keepsing
  est store m1
  quietly reghdfe lnGI ADP c.ADP#c.ER3 $firmcontrols $indcontrols, absorb(year stockcd) cluster(stockcd)  keepsing
  est store m2
  esttab m1 m2,b(%9.3f) se(%9.3f)  obslast star(* 0.1 ** 0.05 *** 0.01) order(ADP c.ADP#c.ER3) compress nogap  stat(N r2_a, fmt(%9.0f  %9.3f)) varwidth(20) 

*列(7)-列(8)
  rename dqsttreat ER4
  quietly reghdfe lnGI ADP c.ADP#c.ER4, absorb(year stockcd) cluster(stockcd)  keepsing
  est store m1
  quietly reghdfe lnGI ADP c.ADP#c.ER4 $firmcontrols $indcontrols, absorb(year stockcd) cluster(stockcd)  keepsing
  est store m2
  esttab m1 m2,b(%9.3f) se(%9.3f)  obslast star(* 0.1 ** 0.05 *** 0.01)  order(ADP c.ADP#c.ER4) compress nogap  stat(N r2_a, fmt(%9.0f  %9.3f)) varwidth(20) 

*~~~表6 异质性绿色创新: 策略性创新VS实质性创新~~~*   
  quietly reghdfe AInvention1 ADP $firmcontrols $indcontrols, absorb(year stockcd) cluster(stockcd) keepsing
  est store m1
  quietly reghdfe AInvention2 ADP $firmcontrols $indcontrols, absorb(year stockcd) cluster(stockcd) keepsing resid
  est store m2
  *系数差异检验
  predict AInvention2hat,xbd
  gen diff1 = AInvention1-AInvention2hat
  reghdfe diff1 ADP $firmcontrols $indcontrols, absorb(year stockcd) cluster(stockcd) keepsing

  quietly reghdfe GInvention1 ADP $firmcontrols $indcontrols, absorb(year stockcd) cluster(stockcd) keepsing
  est store m3
  quietly reghdfe GInvention2 ADP $firmcontrols $indcontrols, absorb(year stockcd) cluster(stockcd) keepsing resid
  est store m4
  *系数差异检验
  predict GInvention2hat,xbd
  gen diff2 = GInvention1 - GInvention2hat
  reghdfe diff2 ADP $firmcontrols $indcontrols, absorb(year stockcd) cluster(stockcd) keepsing
  
  esttab m1 m2 m3 m4,b(%9.3f) se(%9.3f)  obslast star(* 0.1 ** 0.05 *** 0.01) compress nogap  stat(N r2_a, fmt(%9.0f  %9.3f)) varwidth(20) 
  
*~~~表7 异质性绿色创新：组织方式与目标靶向~~~*   
   quietly reghdfe depGI ADP $firmcontrols $indcontrols, absorb(year stockcd) cluster(stockcd) keepsing
   est store m1
   quietly reghdfe coopGI ADP $firmcontrols $indcontrols, absorb(year stockcd) cluster(stockcd) keepsing resid
   est store m2
   predict coopGIhat,xbd
   gen diff3 = depGI-coopGIhat
   reghdfe diff3 ADP $firmcontrols $indcontrols, absorb(year stockcd) cluster(stockcd) keepsing
   
   quietly reghdfe orGI ADP $firmcontrols $indcontrols, absorb(year stockcd) cluster(stockcd) keepsing resid
   est store m3
   predict orGIhat,xbd
   quietly reghdfe wmGI ADP $firmcontrols $indcontrols, absorb(year stockcd) cluster(stockcd) keepsing
   est store m4
   gen diff4 = wmGI - orGIhat
   reghdfe diff4 ADP $firmcontrols $indcontrols, absorb(year stockcd) cluster(stockcd) keepsing
   
  esttab m1 m2 m3 m4,b(%9.3f) se(%9.3f)  obslast star(* 0.1 ** 0.05 *** 0.01)  order(ADP) compress nogap  stat(N r2_a, fmt(%9.0f  %9.3f)) varwidth(20) 

